EDAM: Environmental Data Acquisition Module
================================
Release v\ |version|. (:ref:`Installation <install>`)

.. toctree::
    :maxdepth: 4
    :caption: Contents

    edam


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
